==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/WUBA.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+12)
#define CT_v193	((void*)startLabel+44)
#define F0_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+52)
#define FN_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+80)
#define CT_v197	((void*)startLabel+132)
#define CF_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+140)
#define CT_v201	((void*)startLabel+240)
#define PP_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+272)
#define PC_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+272)
#define ST_v195	((void*)startLabel+272)
#define PP_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+293)
#define PC_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+293)
#define ST_v192	((void*)startLabel+293)
#define ST_v199	((void*)startLabel+316)
#define PS_v196	((void*)startLabel+336)
#define PS_v194	((void*)startLabel+348)
#define PS_v200	((void*)startLabel+360)
#define PS_v198	((void*)startLabel+372)
#define PS_v191	((void*)startLabel+384)
void FR_NHC_46BinArray_46hs_95wUBA_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok3[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok3[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];

static Node startLabel[] = {
  bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v193)
,	/* FN_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PUSH_ARG_I3,EVAL)
, bytes2word(POP_I1,PRIMITIVE,NOP,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v192)
,	/* CT_v193: (byte 0) */
  HW(0,3)
, 0
,	/* F0_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA_35),3)
, useLabel(PS_v191)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v197)
,	/* FN_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v196)
, 0
, 0
, 0
, 0
, 110022
, useLabel(ST_v195)
,	/* CT_v197: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
, useLabel(PS_v194)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok3))
, useLabel(F0_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v201)
,};
Node FN_NHC_46BinArray_46wUBA[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_ARG_I1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(ZAP_ARG_I1,ZAP_ARG_I2,ZAP_ARG_I3,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,3,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v200)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v199)
,	/* CT_v201: (byte 0) */
  HW(1,3)
, 0
,};
Node F0_NHC_46BinArray_46wUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46wUBA),3)
, useLabel(PS_v198)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
,	/* PP_NHC_46BinArray_46hs_95wUBA: (byte 0) */
 	/* PC_NHC_46BinArray_46hs_95wUBA: (byte 0) */
 	/* ST_v195: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(119,85,66,65)
,	/* PP_NHC_46BinArray_46hs_95wUBA_35: (byte 1) */
 	/* PC_NHC_46BinArray_46hs_95wUBA_35: (byte 1) */
 	/* ST_v192: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,119,85,66)
, bytes2word(65,35,0,0)
,};
Node PP_NHC_46BinArray_46wUBA[] = {
 };
Node PC_NHC_46BinArray_46wUBA[] = {
 	/* ST_v199: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,119,85,66)
, bytes2word(65,0,0,0)
,	/* PS_v196: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95wUBA)
, useLabel(PC_NHC_46Internal_46_95mkIOok3)
,	/* PS_v194: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95wUBA)
, useLabel(PC_NHC_46BinArray_46hs_95wUBA)
,	/* PS_v200: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46wUBA)
, useLabel(PC_NHC_46BinArray_46hs_95wUBA)
,	/* PS_v198: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46wUBA)
, useLabel(PC_NHC_46BinArray_46wUBA)
,	/* PS_v191: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95wUBA_35)
, useLabel(PC_NHC_46BinArray_46hs_95wUBA_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_wUBA" NHC.BinArray.hs_wUBA# 3 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int -> Prelude.Int */
extern HsInt hs_wUBA(void*,HsInt,HsInt);
#ifdef PROFILE
static SInfo pf_hs_wUBA = {"NHC.BinArray","NHC.BinArray.hs_wUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95wUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  HsInt arg3;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);
  nodeptr = C_GETARG1(3);
  IND_REMOVE(nodeptr);
  arg3 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_wUBA(arg1,arg2,arg3);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_wUBA);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/WUBA.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+12)
#define CT_v197	((void*)startLabel+44)
#define F0_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+52)
#define FN_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+80)
#define CT_v201	((void*)startLabel+132)
#define CF_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+140)
#define CT_v205	((void*)startLabel+240)
#define PP_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+272)
#define PC_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+272)
#define ST_v199	((void*)startLabel+272)
#define PP_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+293)
#define PC_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+293)
#define ST_v196	((void*)startLabel+293)
#define ST_v203	((void*)startLabel+316)
#define PS_v200	((void*)startLabel+336)
#define PS_v198	((void*)startLabel+348)
#define PS_v204	((void*)startLabel+360)
#define PS_v202	((void*)startLabel+372)
#define PS_v195	((void*)startLabel+384)
void FR_NHC_46BinArray_46hs_95wUBA_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok3[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok3[];

static Node startLabel[] = {
  bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v197)
,	/* FN_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PUSH_ARG_I3,EVAL)
, bytes2word(POP_I1,PRIMITIVE,NOP,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v196)
,	/* CT_v197: (byte 0) */
  HW(0,3)
, 0
,	/* F0_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA_35),3)
, useLabel(PS_v195)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v201)
,	/* FN_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v200)
, 0
, 0
, 0
, 0
, 110001
, useLabel(ST_v199)
,	/* CT_v201: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
, useLabel(PS_v198)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok3))
, useLabel(F0_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v205)
,};
Node FN_NHC_46BinArray_46wUBA[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_ARG_I1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(ZAP_ARG_I1,ZAP_ARG_I2,ZAP_ARG_I3,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,3,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v204)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v203)
,	/* CT_v205: (byte 0) */
  HW(1,3)
, 0
,};
Node F0_NHC_46BinArray_46wUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46wUBA),3)
, useLabel(PS_v202)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
,	/* PP_NHC_46BinArray_46hs_95wUBA: (byte 0) */
 	/* PC_NHC_46BinArray_46hs_95wUBA: (byte 0) */
 	/* ST_v199: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(119,85,66,65)
,	/* PP_NHC_46BinArray_46hs_95wUBA_35: (byte 1) */
 	/* PC_NHC_46BinArray_46hs_95wUBA_35: (byte 1) */
 	/* ST_v196: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,119,85,66)
, bytes2word(65,35,0,0)
,};
Node PP_NHC_46BinArray_46wUBA[] = {
 };
Node PC_NHC_46BinArray_46wUBA[] = {
 	/* ST_v203: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,119,85,66)
, bytes2word(65,0,0,0)
,	/* PS_v200: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95wUBA)
, useLabel(PC_NHC_46Internal_46_95mkIOok3)
,	/* PS_v198: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95wUBA)
, useLabel(PC_NHC_46BinArray_46hs_95wUBA)
,	/* PS_v204: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46wUBA)
, useLabel(PC_NHC_46BinArray_46hs_95wUBA)
,	/* PS_v202: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46wUBA)
, useLabel(PC_NHC_46BinArray_46wUBA)
,	/* PS_v195: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95wUBA_35)
, useLabel(PC_NHC_46BinArray_46hs_95wUBA_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_wUBA" NHC.BinArray.hs_wUBA# 3 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int -> Prelude.Int */
extern HsInt hs_wUBA(void*,HsInt,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95wUBA_35 = {"NHC.BinArray","NHC.BinArray.hs_wUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95wUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  HsInt arg3;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);
  nodeptr = C_GETARG1(3);
  IND_REMOVE(nodeptr);
  arg3 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_wUBA(arg1,arg2,arg3);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95wUBA_35);
  C_RETURN(nodeptr);
}
